==> nextcloud-app-calendar-1.5.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/lv.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Kalendārs",
    "%s has published the calendar \"%s\"" : "%s publicējis kalendāru \"%s\"",
    "Too many redirects. Aborting ..." : "Pārāk daudz novirzīšanas gadījumu. Pārtrauc ...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Attālais serveris nedeva mums piekļuvi kalendāram (HTTP {%s} kļūda)",
    "Error connecting to remote server" : "Kļūda, veidojot savienojumu ar attālo serveri",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Attālā servera resursu pieprasījumam, radās kļūda. Tas varētu būt saistīts ar sertifikātu neatbilstība",
    "Error requesting resource on remote server" : "Attālā servera resursu pieprasījuma kļūda",
    "Individual" : "Individuāls",
    "Group" : "Grupa",
    "Resource" : "Resurss",
    "Room" : "Istaba",
    "Unknown" : "Nezināms",
    "Required" : "Nepieciešams",
    "Optional" : "Neobligāts",
    "Does not attend" : "Neieradās",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Jūs atrodaties nezināmā laika zonā ({tz}), pārslēdz atpakaļ uz UTC",
    "Please create a calendar first." : "Lūdzu vispirms izveido kalendāru.",
    "New event" : "Jauns notikums",
    "CalDAV address for clients" : "CalDAV adrese klientiem",
    "Error saving WebCal-calendar" : "Kļūda saglabājot WebCal-calendar",
    "EMail has been sent." : "E-pasts ir nosūtīts.",
    "There was an issue while sending your EMail." : "Radās problēma, nosūtot šo e-pastu.",
    "group" : "grupa",
    "Details" : "Detaļas",
    "Attendees" : "Apmeklētāji",
    "Reminders" : "Atgādinājumi",
    "Repeating" : "Atkārtojas",
    "When shared show full event" : "Ja koplietots, tad rādīt pilnu notikumu",
    "When shared show only busy" : "Ja koplietots, tad rādīt tikai aizņemts",
    "When shared hide this event" : "Ja koplietots, tad paslēpt notikumu",
    "Confirmed" : "Apstiprināts",
    "Tentative" : "Mēģinājums",
    "Cancelled" : "Atcelts",
    "Please add a title!" : "Lūdzu pievieno virsrakstu!",
    "Please select a calendar!" : "Lūdzu izvēlies kalendāru!",
    "Global" : "Globāls",
    "None" : "Nav",
    "Every day" : "Katru dienu",
    "Every week" : "Katru nedēļu",
    "Every month" : "Katru mēnesi",
    "Every year" : "Katru gadu",
    "never" : "nekad",
    "after" : "pēc",
    "How about getting started by importing some calendars?" : "Kā uzsākt darbu, importējot dažus kalendārus?",
    "At time of event" : "Notikuma laikā",
    "5 minutes before" : "5 minūtes pirms",
    "10 minutes before" : "10 minūtes pirms",
    "15 minutes before" : "15 minūtes pirms",
    "30 minutes before" : "30 minūtes pirms",
    "1 hour before" : "1 stundu pirms",
    "2 hours before" : "2 stundas pirms",
    "Custom" : "Pielāgots",
    "Audio" : "Audio",
    "E Mail" : "E-pasts",
    "Pop up" : "Paziņojums",
    "sec" : "sek",
    "min" : "min",
    "hours" : "stundas",
    "days" : "dienas",
    "week" : "nedēļa",
    "before" : "pirms",
    "start" : "sākums",
    "end" : "beigas",
    "Editing reminders of unknown type not supported." : "Nezināma tipa atgādinājumu rediģēšana netiek atbalstīta",
    "Week {number} of {year}" : "{number} nedēļa no {year}",
    "Successfully imported" : "Veiksmīgi importēts",
    "Partially imported, 1 failure" : "Daļēji importēts, 1 kļūda",
    "Partially imported, {n} failures" : "Daļēji importēts, {n} kļūdas",
    "Audio alarm" : "Audio signāls",
    "Pop-up" : "Paziņojums",
    "E-Mail" : "E-pasts",
    "{type} {time} before the event starts" : "{type} {time} pirms notikuma sākuma",
    "{type} {time} before the event ends" : "{type} {time} pirms notikuma beigām",
    "{type} {time} after the event starts" : "{type} {time} pēc notikuma sākuma",
    "{type} {time} after the event ends" : "{type} {time} pēc notikuma beigām",
    "{type} at the event's start" : "{type} notikuma sākumā",
    "{type} at the event's end" : "{type} notikuma beigās",
    "{type} at {time}" : "{type}  {time}",
    "{calendar} shared by {owner}" : "{calendar} koplietoja {owner}",
    "Title of the Event" : "Notikuma nosaukums",
    "All day Event" : "Visas dienas notikums",
    "Delete" : "Dzēst",
    "Cancel" : "Atcelt",
    "More ..." : "Vairāk ...",
    "Create" : "Izveidot",
    "Update" : "Atjaunināt",
    "Close" : "Aizvērt",
    "Location" : "Vieta",
    "Description" : "Apraksts",
    "Event status" : "Notikum statuss",
    "Visibility when sharing" : "Redzamība ja koplietots",
    "Export" : "Eksportēt",
    "Hello," : "Sveicināti,",
    "Click here to access it" : "Noklikšķiniet šeit, lai piekļūtu",
    "Cheers!" : "Priekā!",
    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Sakarā ar iepriekšēju kļūdu, kalendārs šobrīd nevar nodrošināt \"asset pipeline\" funkcionalitāti.",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Sazinieties ar savu administratoru un palūdziet viņam atslēgt \"asset-pipeline.enabled\" konfigurācijas opciju.",
    "Day" : "Diena",
    "Week" : "Nedēļa",
    "Month" : "Mēnesis",
    "Today" : "Šodien",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Daži notikumi kalendārā ir bojāti. Papildus informācijai pārbadiet JS konsoli.",
    "Share Calendar" : "Koplietot kalendāru",
    "Shared" : "Koplietots",
    "More" : "Vairāk",
    "Edit" : "Rediģēt",
    "Link" : "Saite",
    "iCal link" : "iCal saite",
    "Download" : "Lejupielādēt",
    "Share with users or groups" : "Koplietot ar lietotājiem vai grupām",
    "can edit" : "var rediģēt",
    "Share link" : "Koplietot saiti",
    "Public access" : "Publiska piekļuve",
    "Email link to person" : "Sūtīt saiti personai pa e-pastu",
    "Send" : "Sūtīt",
    "New Calendar" : "Jauns kalendārs",
    "Name" : "Nosaukums",
    "New Subscription" : "Jauns abonements",
    "Go back" : "Atpakaļ",
    "Go forward" : "Uz priekšu",
    "Edit event" : "Rediģēt notikumu",
    "Delete Event" : "Dzēst notikumu",
    "Save Event" : "Saglabāt notikumu",
    "Time" : "Laiks",
    "Type" : "Tips",
    "Relative" : "Relatīvs",
    "Absolute" : "Absolūts",
    "Repeat" : "Atkārtot",
    "times every" : "reizes katru",
    "Add" : "Pievienot",
    "E-Mail address of attendee" : "Dalībnieka e-pasta adrese",
    "Please add your email address in the personal settings in order to add attendees." : "Lai pievienotu dalībniekus, personīgajos iestatījumos pievieno savu e-pasta adresi",
    "from" : "no",
    "to" : "līdz",
    "This event's repeating rule is not supported yet." : "Šī notikuma atkārtošanās vēl netiek atbalstīta.",
    "Support for advanced rules will be added with subsequent updates." : "Uzlaboti noteikumi tiks pievienotu turpmākajos atjauninājumos.",
    "Reset repeating rule" : "Dzēst atkārtošanās noteikumu",
    "Repeat every ..." : "Atkārtot katru ...",
    "end repeat ..." : "un atkārtot ...",
    "times" : "reizes",
    "Import Calendars" : "Importēt kalendārus",
    "Import canceled" : "Imports atcelts",
    "Analyzing calendar" : "Analizē kalendāru",
    "The file contains objects incompatible with the selected calendar" : "Datne satur nesaderīgu objektu ar izvēlēto kalendāru",
    "New calendar" : "Jauns kalendārs",
    "File is empty" : "Fails ir tukšs",
    "Import scheduled" : "Imports ielikts grafikā",
    "Publish URL" : "Publicēt URL",
    "Settings & import" : "Iestatījumi un imports",
    "Skip simple event editor" : "Izlaist vienkāršoto notikuma redaktoru",
    "Show week numbers" : "Rādīt nedēļu numurus",
    "Import calendar" : "Importēt kalendāru",
    "No Calendars selected for import" : "Nav izvēlēti kalendāri importēšai",
    "Primary CalDAV address" : "Primārā CalDAV adrese",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV adrese"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");

==> nextcloud-app-calendar-1.5.6-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/lv.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Kalendārs",
    "Hello," : "Sveicināti,",
    "Cheers!" : "Priekā!",
    "Too many redirects. Aborting ..." : "Pārāk daudz novirzīšanas gadījumu. Pārtrauc ...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Attālais serveris nedeva mums piekļuvi kalendāram (HTTP {%s} kļūda)",
    "Error connecting to remote server" : "Kļūda, veidojot savienojumu ar attālo serveri",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Attālā servera resursu pieprasījumam, radās kļūda. Tas varētu būt saistīts ar sertifikātu neatbilstība",
    "Error requesting resource on remote server" : "Attālā servera resursu pieprasījuma kļūda",
    "Individual" : "Individuāls",
    "Group" : "Grupa",
    "Resource" : "Resurss",
    "Room" : "Istaba",
    "Unknown" : "Nezināms",
    "Required" : "Nepieciešams",
    "Optional" : "Neobligāts",
    "Does not attend" : "Neieradās",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Jūs atrodaties nezināmā laika zonā ({tz}), pārslēdz atpakaļ uz UTC",
    "Please create a calendar first." : "Lūdzu vispirms izveido kalendāru.",
    "New event" : "Jauns notikums",
    "CalDAV address for clients" : "CalDAV adrese klientiem",
    "Error saving WebCal-calendar" : "Kļūda saglabājot WebCal-calendar",
    "WebDAV address for subscriptions" : "WebDAV adrese abonementiem",
    "Email has been sent." : "E-pasts nosūtīts.",
    "There was an issue while sending your email." : "Notikusi kļūda sūtot e-pastu.",
    "group" : "grupa",
    "Details" : "Detaļas",
    "Attendees" : "Apmeklētāji",
    "Reminders" : "Atgādinājumi",
    "Repeating" : "Atkārtojas",
    "When shared show full event" : "Ja koplietots, tad rādīt pilnu notikumu",
    "When shared show only busy" : "Ja koplietots, tad rādīt tikai aizņemts",
    "When shared hide this event" : "Ja koplietots, tad paslēpt notikumu",
    "Confirmed" : "Apstiprināts",
    "Tentative" : "Mēģinājums",
    "Cancelled" : "Atcelts",
    "Global" : "Globāls",
    "None" : "Nav",
    "Every day" : "Katru dienu",
    "Every week" : "Katru nedēļu",
    "Every month" : "Katru mēnesi",
    "Every year" : "Katru gadu",
    "never" : "nekad",
    "after" : "pēc",
    "How about getting started by importing some calendars?" : "Kā uzsākt darbu, importējot dažus kalendārus?",
    "At time of event" : "Notikuma laikā",
    "5 minutes before" : "5 minūtes pirms",
    "10 minutes before" : "10 minūtes pirms",
    "15 minutes before" : "15 minūtes pirms",
    "30 minutes before" : "30 minūtes pirms",
    "1 hour before" : "1 stundu pirms",
    "2 hours before" : "2 stundas pirms",
    "Custom" : "Pielāgots",
    "Audio" : "Audio",
    "Email" : "E-pasts",
    "Pop-up" : "Paziņojums",
    "sec" : "sek",
    "min" : "min",
    "hours" : "stundas",
    "days" : "dienas",
    "week" : "nedēļa",
    "before" : "pirms",
    "start" : "sākums",
    "end" : "beigas",
    "Editing reminders of unknown type not supported." : "Nezināma tipa atgādinājumu rediģēšana netiek atbalstīta",
    "Week {number} of {year}" : "{number} nedēļa no {year}",
    "Successfully imported" : "Veiksmīgi importēts",
    "Partially imported, 1 failure" : "Daļēji importēts, 1 kļūda",
    "Partially imported, {n} failures" : "Daļēji importēts, {n} kļūdas",
    "Audio alarm" : "Audio signāls",
    "{type} {time} before the event starts" : "{type} {time} pirms notikuma sākuma",
    "{type} {time} before the event ends" : "{type} {time} pirms notikuma beigām",
    "{type} {time} after the event starts" : "{type} {time} pēc notikuma sākuma",
    "{type} {time} after the event ends" : "{type} {time} pēc notikuma beigām",
    "{type} at the event's start" : "{type} notikuma sākumā",
    "{type} at the event's end" : "{type} notikuma beigās",
    "{type} at {time}" : "{type}  {time}",
    "{calendar} shared by {owner}" : "{calendar} koplietoja {owner}",
    "Please enter a valid WebCal-URL" : "Lūdzu norādiet derīgu WebCal adresi",
    "Severe error in webcal proxy. Please contact administrator for more information." : "Kļūda WebCal protokola maršrutēšanā. Sazinieties ar administratoru, lai uzzinātu vairāk.",
    "Title of the Event" : "Notikuma nosaukums",
    "Starts" : "Sākas",
    "Ends" : "Beidzas",
    "All day Event" : "Visas dienas notikums",
    "Delete" : "Dzēst",
    "Cancel" : "Atcelt",
    "More ..." : "Vairāk ...",
    "Create" : "Izveidot",
    "Update" : "Atjaunināt",
    "Close" : "Aizvērt",
    "Location" : "Vieta",
    "Description" : "Apraksts",
    "Event status" : "Notikum statuss",
    "Visibility when sharing" : "Redzamība ja koplietots",
    "Export" : "Eksportēt",
    "%s has published the calendar %s" : "%s dalijās ar kalendāru %s",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Ņemiet vērā, ka %s dalijās ar kalendāru {boldstart}%s{boldend}.",
    "Click here to access it" : "Noklikšķiniet šeit, lai piekļūtu",
    "We wanted to inform you that %s has published the calendar %s." : "Ņemiet vērā, ka %s dalījās ar kalendāru %s.",
    "Click on the link below to access it" : "Spiediet uz saites zemāk, lai tam piekļūtu",
    "Day" : "Diena",
    "Week" : "Nedēļa",
    "Month" : "Mēnesis",
    "Today" : "Šodien",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Daži notikumi kalendārā ir bojāti. Papildus informācijai pārbadiet JS konsoli.",
    "Share Calendar" : "Koplietot kalendāru",
    "Shared" : "Koplietots",
    "More" : "Vairāk",
    "Edit" : "Rediģēt",
    "Link" : "Saite",
    "iCal link" : "iCal saite",
    "Download" : "Lejupielādēt",
    "Share with users or groups" : "Koplietot ar lietotājiem vai grupām",
    "can edit" : "var rediģēt",
    "Share link" : "Koplietot saiti",
    "Public access" : "Publiska piekļuve",
    "Email link to person" : "Sūtīt saiti personai pa e-pastu",
    "Send" : "Sūtīt",
    "New Calendar" : "Jauns kalendārs",
    "Name" : "Nosaukums",
    "New Subscription" : "Jauns abonements",
    "Go back" : "Atpakaļ",
    "Go forward" : "Uz priekšu",
    "Calendar does not exist" : "Kalendārs nepastāv",
    "Maybe you got a wrong link or the calendar was unshared?" : "Iespējams jūs saņēmāt nepareizu saiti, vai kalendārs vairs nav koplietots.",
    "Edit event" : "Rediģēt notikumu",
    "Delete Event" : "Dzēst notikumu",
    "Save Event" : "Saglabāt notikumu",
    "Time" : "Laiks",
    "Type" : "Tips",
    "Relative" : "Relatīvs",
    "Absolute" : "Absolūts",
    "Repeat" : "Atkārtot",
    "times every" : "reizes katru",
    "Add" : "Pievienot",
    "Email address of attendee" : "Dalībnieka e-pasta adrese",
    "Please add your email address in the personal settings in order to add attendees." : "Lai pievienotu dalībniekus, personīgajos iestatījumos pievieno savu e-pasta adresi",
    "from" : "no",
    "to" : "līdz",
    "This event's repeating rule is not supported yet." : "Šī notikuma atkārtošanās vēl netiek atbalstīta.",
    "Support for advanced rules will be added with subsequent updates." : "Uzlaboti noteikumi tiks pievienotu turpmākajos atjauninājumos.",
    "Reset repeating rule" : "Dzēst atkārtošanās noteikumu",
    "Repeat every ..." : "Atkārtot katru ...",
    "end repeat ..." : "un atkārtot ...",
    "times" : "reizes",
    "Import Calendars" : "Importēt kalendārus",
    "Import canceled" : "Imports atcelts",
    "Analyzing calendar" : "Analizē kalendāru",
    "The file contains objects incompatible with the selected calendar" : "Datne satur nesaderīgu objektu ar izvēlēto kalendāru",
    "New calendar" : "Jauns kalendārs",
    "File is empty" : "Fails ir tukšs",
    "Import scheduled" : "Imports ielikts grafikā",
    "%s shared the calendar <strong>%s</strong> with you" : "%s koplietoja kalendāru <strong>%s</strong> ar jums",
    "Embed" : "Iestrādāt",
    "Publish URL" : "Publicēt URL",
    "Settings & import" : "Iestatījumi un imports",
    "Skip simple event editor" : "Izlaist vienkāršoto notikuma redaktoru",
    "Show week numbers" : "Rādīt nedēļu numurus",
    "Import calendar" : "Importēt kalendāru",
    "No Calendars selected for import" : "Nav izvēlēti kalendāri importēšai",
    "Primary CalDAV address" : "Primārā CalDAV adrese",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV adrese",
    "Subscribe" : "Abonēt"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
